package com.goldenwater.gx.service.impl;

import com.goldenwater.gx.domain.DocFile;
import com.goldenwater.gx.mapper.DocFileMapper;
import com.goldenwater.gx.service.IDocFileService;
import org.springframework.stereotype.Service;

import jakarta.annotation.Resource;
import java.util.List;

@Service("docFileService")
public class DocFileServiceImpl implements IDocFileService {

    @Resource
    private DocFileMapper docFileMapper;

    @Override
    public List<DocFile> selectFileList(Long dirId) {
        return docFileMapper.selectFileList(dirId);
    }

    @Override
    public DocFile selectFileById(Long id) {
        return docFileMapper.selectFileById(id);
    }

    @Override
    public int insertFile(DocFile file) {
        return docFileMapper.insertFile(file);
    }

    @Override
    public int updateFile(DocFile file) {
        return docFileMapper.updateFile(file);
    }

    @Override
    public int deleteFileById(Long id) {
        return docFileMapper.deleteFileById(id);
    }
}
